#!/bin/sh
#
# Package: auto-pilot
# Erez Zadok <ezk@cs.sunysb.edu>
# Copyright (c) 2001-2006 Stony Brook University

# Use our common settings

source commonsettings || exit $?

# If there is a $1, then use a type
if [ -z "$1" ] ; then
	echo "$0: You must specify a file system type." 1>&2
	exit 1	
fi
FSTYPE=$1

if [ -z "$FSTYPE" ] ; then
	echo "You must specify a file system type." 1>&2
	exit 1
fi

if [ "$FSTYPE" = "none" ] ; then
	exit 0
fi

if [ -z "$TESTROOT" ] ; then
	echo "You must specify the TESTROOT as an environment variable."
	exit 1
fi

function ap_initfs() {
	local FS
	local BLOCKS

	if [ ! -z "$1" ]; then
		FS=$1
	fi

	# The underlying device to be formatted on every run (e.g., /dev/hda6)
	if [ -z "$TESTDEV" ] ; then
		echo "TESTDEV not set!";
		exit 1
	fi


	if [ -z "$FSSIZE"  ] ;then
		BLOCKS=
	else
		BLOCKS=$((($FSSIZE * 1024 * 1024) / $BLOCKSIZE))
	fi

	EXTRAOPTS=`ap_hook mkfsopts $FS $TESTDEV $BLOCKSIZE $FSSIZE` || return $?

	if [ "$FS" = "ext2" -o "$FS" = "ext3" ]; then
		if [ "$FS" = "ext3" ] ; then
			JOURNAL="-j"
		fi
		ap_action $"Creating $FS File system on $TESTDEV" mke2fs -b "$BLOCKSIZE" $JOURNAL $EXTRAOPTS "$TESTDEV" $BLOCKS || return $?
		ap_action $"Tuning $FS File system on $TESTDEV" tune2fs -c 0 -i 0 $TESTDEV || return $?

	elif [ "$FS" = "reiserfs" ] ; then
		ap_action $"Creating $FS File system on $TESTDEV" mkfs -t reiserfs $EXTRAOPTS -f -f "$TESTDEV" $BLOCKS || return $?
	else
		ap_requirehook mkfs $FS "$TESTDEV" "$BLOCKSIZE" "$FSSIZE" || ap_action "Unknown file system type $FS." false
	fi

	ap_hook tunefs $FS "$TESTDEV"

	return 0
}

ap_unmount $TESTROOT
[ -z "$TESTDEV" ] || ap_unmount $TESTDEV

if [ "$FORMAT" = "1" ] ; then
	ap_initfs ${FSTYPE}
fi

# DOMOUNT is an internal variable that is used by the hooks, if you don't want
# to mount the file system, then you should not use fs-setup.sh.
DOMOUNT=1
if [ -z "$TESTDEV" ] ; then
	TESTDEV=none
	UNDOTD=1
fi
ap_hook mount "$FSTYPE" "$TESTDEV" "$TESTROOT"
if [ "$UNDOTD" = "1" ] ; then
	TESTDEV=""
fi

if [ "$DOMOUNT" = "1" ] ; then
	if [ -z "TESTDEV" ] ; then
		echo "Unless your hooks do the mounting for you, then you must"
		echo "specify the TESTDEV as an environment variable."
	fi
	EXTRAOPTS=`ap_hook mountopts $FSTYPE $TESTDEV $TESTROOT` || return $?
	ap_action $"Mounting $TESTDEV on $TESTROOT" mount -t "$FSTYPE" $EXTRAOPTS "$TESTDEV" "$TESTROOT"
fi
ap_hook postmount "$FSTYPE" "$TESTDEV" "$TESTROOT"

if [ ! -d "$TESTDIR" ] ; then
	ap_action $"Creating testdir..." mkdir -p ${TESTDIR}
fi

echo "${FSTYPE} setup completed."

exit 0
